==> owncloud_8.0.16.orig.tar.gz: owncloud/apps/activity/l10n/fa.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "فعالیت",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "%2$s created %1$s" : "%2$s مورد %1$s را ایجاد کرد",
    "%1$s was created in a public folder" : "%1$s در پوشه ی عمومی ایجاد شد",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "%2$s changed %1$s" : "%2$s مورد %1$s را تغییر داد",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "%2$s deleted %1$s" : "%2$s مورد %1$s را حذف کرد",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید",
    "%2$s restored %1$s" : "%2$s %1$s را بازگردانی کرد",
    "You shared %1$s with %2$s" : "شما %1$s را با %2$s به اشتراک گذاشتید",
    "You shared %1$s with group %2$s" : "شما %1$s را با گروه %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with you" : "%2$s مورد %1$s را با شما به اشتراک گذاشت",
    "You shared %1$s via link" : "شما %1$s را توسط پیوند به اشتراک گذاشتید",
    "Activity notification" : "هشدارهای فعالیت",
    "All Activities" : "تمام فعالیت ها",
    "Activities by you" : "فعالیت های مربوط به شما",
    "Activities by others" : "فعالیت های انجام شده توسط دیگران",
    "Shares" : "موارد به اشتراک گذاشته",
    "Files" : "فایل ها",
    "in %s" : "در %s",
    "%s and %s" : "%s و %s",
    ", " : "رشته های ترجمه نشده",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s و <strong class=\"tooltip\" title=\"%s\">%n بیشتر</strong>"],
    "%s and %n more::%s and %n more" : ["%s و %s بیشتر"],
    "Hello %s," : "سلام %s",
    "You are receiving this email because in the last hour the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک ساعت گذشته موارد زیر در %s اتفاق افتاده است",
    "You are receiving this email because in the last day the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک روز گذشته موارد زیر در %s اتفاق افتاده است",
    "You are receiving this email because in the last week the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک هفته گذشته موارد زیر در %s اتفاق افتاده است",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "وقتی که از%s خود استفاده کنید لیستی از وقایع را اینجا مشاهده خواهید کرد.",
    "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد",
    "Enable RSS feed" : "فعالسازی فید RSS",
    "Notifications" : "هشدارها",
    "Mail" : "ایمیل",
    "Stream" : "پخش",
    "List your own actions in the stream" : "اعمال شخصی تان در پخش را لیست کنید",
    "Notify about your own actions via email" : "اطلاع رسانی درباره اعمال شخصی تان با ایمیل",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "Send emails:" : "ارسال ایمیل ها:",
    "Hourly" : "ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفتهگی",
    "Activity feed" : "فید فعالیت",
    "Personal activity feed for %s" : "فعالیت شخصی فید برای %s"
},
"nplurals=1; plural=0;");

==> owncloud_8.1.12.orig.tar.gz: owncloud/apps/activity/l10n/fa.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "فعالیت",
    "Personal activity feed for %s" : "فعالیت شخصی فید برای %s",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "Activity notification" : "هشدارهای فعالیت",
    "All Activities" : "تمام فعالیت ها",
    "Activities by you" : "فعالیت های مربوط به شما",
    "Activities by others" : "فعالیت های انجام شده توسط دیگران",
    "in %s" : "در %s",
    "%s and %s" : "%s و %s",
    ", " : "رشته های ترجمه نشده",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s و <strong class=\"tooltip\" title=\"%s\">%n بیشتر</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s و %s بیشتر"],
    "Hello %s," : "سلام %s",
    "You are receiving this email because in the last hour the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک ساعت گذشته موارد زیر در %s اتفاق افتاده است",
    "You are receiving this email because in the last day the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک روز گذشته موارد زیر در %s اتفاق افتاده است",
    "You are receiving this email because in the last week the following things happened at %s" : "شما این ایمیل را دریافت کردید زیرا در یک هفته گذشته موارد زیر در %s اتفاق افتاده است",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "هشدارها",
    "Mail" : "ایمیل",
    "Stream" : "پخش",
    "List your own actions in the stream" : "اعمال شخصی تان در پخش را لیست کنید",
    "Notify about your own actions via email" : "اطلاع رسانی درباره اعمال شخصی تان با ایمیل",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "Send emails:" : "ارسال ایمیل ها:",
    "Hourly" : "ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفتهگی",
    "Activity feed" : "فید فعالیت",
    "Enable RSS feed" : "فعالسازی فید RSS",
    "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد",
    "Files" : "فایل ها"
},
"nplurals=1; plural=0;");
